
Pet Store
=========

Version :openapi:version:`petstore.yaml`

.. sidebar:: Services

    .. openapi:toc:: petstore.yaml

Services
""""""""
.. openapi:: petstore.yaml
    :examples:
    :group:
    :group_examples:
    :entities:

Data Model
""""""""""

.. openapi:model:: petstore.yaml
